<h1 align="center">work-stream</h1>

<a href='https://work-stream.readthedocs.io/zh/latest/?badge=latest'><img src='https://readthedocs.org/projects/work-stream/badge/?version=latest' alt='Documentation Status' /></a>
<a href='https://work-stream.readthedocs.io/zh/latest/?badge=latest'><img src="https://img.shields.io/badge/python-3.6%2B-brightgreen" alt="PyPI - Python Version"></a>
<a href="https://pypi.org/project/work-stream"><img src="https://img.shields.io/badge/pypi-v0.0.2-brightgreen" alt="PyPI - Format"></a>
<a href="https://pypi.org/project/work-stream"><img src="https://img.shields.io/badge/release-0.0.2-brightgreen" alt="Release - Format"></a>

<br>

# 简介

这是一个用于应对运维工作的模块，能够将提前设定好的运维任务流水线式执行，并且支持流程化编排。

<br>

## 特性

- 支持流程状态管理。
- 每个流程/块支持接收上一流程/块的返回值。
- 支持分支流程，需要自己设定判断表达式。
- 支持流程编排。

<br>

## 版本
python3.6+

<br>

## 安装

    pip3 install work-stream

<br>

## 文档

详见:https://work-stream.readthedocs.io/zh/latest/?badge=latest

<br>

